# ResourceGroup


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**desc** | **str** |  | [optional] 
**device_ips** | **[str]** |  | [optional] 
**device_ips** | **[str]** |  | [optional] 
**id** | **{str: (bool, date, datetime, dict, float, int, list, str, none_type)}** |  | [optional] 
**mgmt_sytem_ips_map** | **{str: (str,)}** |  | [optional] 
**name** | **str** |  | [optional] 
**site_ids** | **[int]** |  | [optional] 
**uuid_sytem_ips_map** | **{str: (str,)}** |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


